#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['yaqd_lightcon']

package_data = \
{'': ['*']}

install_requires = \
['yaqd-core>=2020.10.1', 'aiohttp']

extras_require = \
{'dev': ['black', 'pre-commit']}

entry_points = \
{'console_scripts': ['yaqd-lightcon-topas4-motor = '
                     'yaqd_lightcon._lightcon_topas4_motor:LightconTopas4Motor.main',
                     'yaqd-lightcon-topas4-shutter = '
                     'yaqd_lightcon._lightcon_topas4_shutter:LightconTopas4Shutter.main']}

setup(name='yaqd-lightcon',
      version='2021.10.0',
      description='yaq daemons for hardware from Light Conversion',
      author='yaq Developers',
      author_email='git@ksunden.space',
      url='https://yaq.fyi',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
